<?php

/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package tractor-express
 */
?>
<!doctype html>
<html <?php language_attributes(); ?>>

<head>
	<meta charset="<?php bloginfo('charset'); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<link rel="preload" href="<?php echo get_template_directory_uri(); ?>/assets/fonts/Helvetica-Light.woff2" as="font" type="font/woff2" crossorigin>
	<link rel="preload" href="<?php echo get_template_directory_uri(); ?>/assets/fonts/HelveticaNeue.woff2" as="font" type="font/woff2" crossorigin>
	<link rel="preload" href="<?php echo get_template_directory_uri(); ?>/assets/fonts/HelveticaNeueBold.woff2" as="font" type="font/woff2" crossorigin>
	<link rel="preload" href="<?php echo get_template_directory_uri(); ?>/assets/css/fonts/slick.woff" as="font" type="font/woff" crossorigin>
	<link rel="preload" href="<?php echo get_template_directory_uri(); ?>/assets/webfonts/fa-brands-400.woff2" as="font" type="font/woff2" crossorigin>
	<link rel="preload" href="<?php echo get_template_directory_uri(); ?>/assets/webfonts/fa-solid-900.woff2" as="font" type="font/woff2" crossorigin>
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
	<?php wp_body_open(); ?>
	<div id="page" class="site">
		<header id="masthead" class="site-header">
			<div class="header-top">
				<div class="container">
					<div class="row">
						<div class="col-12">
							<div class="header-top-text">
								<div class="site-branding">
									<?php the_custom_logo(); ?>
								</div>
								<?php
									$phone_link    = get_field('phone_number', 'option');
									$address_map   = get_field('address', 'option');
									$facebook_link 		= get_field('facebook_link', 'option');
									$instagram_link = get_field('instagram_link', 'option');
									$linkedin_link  = get_field('linkedin_link', 'option');
									if( !empty($phone_link) ){ ?>
										<div class="header-call">
											<a class="callus" href="<?php echo $phone_link['url']; ?>" title="<?php echo 'Call on ' . $phone_link['title']; ?>"><i class="fas fa-phone"></i><span class="callus"><?php echo $phone_link['title']; ?></span></a>
										</div>
										<?php
									}
									if( !empty($address_map) ){ ?>
										<div class="header-address">
											<a href="<?php echo $address_map['url']; ?>" target="_blank" title="<?php echo $address_map['title']; ?>"><i class="fas fa-map-marker-alt"></i><?php echo $address_map['title']; ?></a>
										</div>
										<?php
									}?>
									<div class="header-fb">
										<?php
										if( !empty($facebook_link) ){ ?>
											<a href="<?php echo $facebook_link; ?>" target="_blank" title="Follow on Facebook"><i class="fab fa-facebook-f"></i></a>
											<?php
										}
										if(!empty($instagram_link) ){ ?>
											<a href="<?php echo $instagram_link; ?>" target="_blank" title="Follow on Instagram"><i class="fab fa-instagram"></i></a>
											<?php
										}
										if(!empty($linkedin_link) ){ ?>
											<a href="<?php echo $linkedin_link; ?>" target="_blank" title="Follow on Linkedin"><i class="fab fa-linkedin-in"></i></a>
											<?php
										}
										?>
										</div>
							</div>
						</div>
					</div>
				</div>
			</div>
			<div class="for-mob">
				<div class="site-branding">
					<?php the_custom_logo(); ?>
				</div>
				<?php
					$phone_number = get_field('phone_number', 'option');
					if( !empty($phone_number) ){ ?>
						<div class="header-call">
							<a class="callus" href="<?php echo $phone_number['url']; ?>" title="<?php echo 'Call on ' . $phone_number['title']; ?>"><i class="fas fa-phone"></i></a>
						</div>
				<?php } ?>
			</div>
			<div class="header-menu">
				<div class="container">
					<div class="row align-items-center">
						<div class="col-lg-9">
							<nav id="site-navigation" class="main-navigation">
								<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
									<span></span>
									<span></span>
									<span></span>
								</button>
								<div class="menu-list-box">
									<?php
									wp_nav_menu(
										array(
											'theme_location' => 'menu-1',
											'menu_id'        => 'primary-menu',
										)
									);
									?>
									<div class="for-mob">
										<?php
											$request_quote    = get_field('request_quote_title', 'option');
											$site_map_address = get_field('address', 'option');
											if( !empty($request_quote) ){ ?>
												<div class="header-btn">
													<button data-bs-toggle="modal" data-bs-target="#schedule_an_estimate_Modal" class="sec-btn mob-header-req-btn" title="<?php echo $request_quote; ?>"><?php echo $request_quote; ?></button>
													<!-- <a href="#contact" data-bs-toggle="modal" data-bs-target="#request_quote" class="sec-btn mob-header-req-btn" title="<?php //echo $request_quote; ?>"><?php //echo $request_quote; ?></a> -->
												</div>
												<?php
											}
											if(!empty($site_map_address) ){ ?>
												<div class="header-address">
													<a href="<?php echo $site_map_address['url']; ?>" target="_blank" title="<?php echo $site_map_address['title']; ?>"><i class="fas fa-map-marker-alt"></i><?php echo $site_map_address['title']; ?></a>
												</div>
										<?php } ?>
										<div class="header-fb">
											<?php
												if( !empty($facebook_link) ){ ?>
													<a href="<?php echo $facebook_link; ?>" target="_blank" title="Follow on Facebook"><i class="fab fa-facebook-f"></i></a>
													<?php
												}

											?>
										</div>
									</div>
								</div>
							</nav>
						</div>
						<?php
							$request_quote_title = get_field('request_quote_title', 'option');
							if(!empty($request_quote_title) ){ ?>
								<div class="col-lg-3">
									<div class="header-btn for-des">
										<button data-bs-toggle="modal" data-bs-target="#schedule_an_estimate_Modal" class="sec-btn mob-header-req-btn" title="<?php echo $request_quote; ?>"><?php echo $request_quote; ?></button>
									<!-- <a href="#contact" class="sec-btn" title="<?php //echo $request_quote_title; ?>"><?php //echo $request_quote_title; ?></a> -->
									</div>
								</div>
						<?php } ?>
					</div>
				</div>
			</div>
		</header>