<?php
/**
 * tractor-express functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package tractor-express
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

if ( ! function_exists( 'tractor_express_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function tractor_express_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on tractor-express, use a find and replace
		 * to change 'tractor-express' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'tractor-express', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'tractor-express' ),
				'footer-menu' => esc_html__( 'Footer Menu', 'tractor-express' ),
				'polycy-menu' => esc_html__( 'Polycy Menu', 'tractor-express' ),
				'seo-menu' => esc_html__( 'SEO Menu', 'tractor-express' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'tractor_express_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'tractor_express_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function tractor_express_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'tractor_express_content_width', 640 );
}
add_action( 'after_setup_theme', 'tractor_express_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function tractor_express_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'tractor-express' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'tractor-express' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'tractor_express_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function tractor_express_scripts() {
	wp_enqueue_style('tractor-express-bootstrap-min', get_template_directory_uri() . '/assets/css/layout.min.css', array(), '20151215');
	wp_enqueue_style('tractor-express-jquery-fancybox-min-css', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css', array(), '20151215');

	wp_enqueue_style( 'tractor-express-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_enqueue_script('jquery');
	wp_style_add_data( 'tractor-express-style', 'rtl', 'replace' );

	wp_enqueue_script('tractor-express-layout-js', get_template_directory_uri() . '/assets/js/layout.js', array(), '20151215', true);
	wp_enqueue_script('tractor-express-slick-min-js', get_template_directory_uri() . '/assets/js/slick.min.js', array(), '20151215', true);
	wp_enqueue_script('tractor-express-simplebar-js', get_template_directory_uri() . '/assets/js/simplebar.js', array(), '20151215', true);
	wp_enqueue_script('tractor-express-jquery-fancybox-min-js', get_template_directory_uri() . '/assets/js/jquery.fancybox.min.js', array(), '20151215', true);
	wp_enqueue_script('tractor-express-Custome-js', get_template_directory_uri() . '/assets/js/custom.js', array(), '20151215', true);
	wp_localize_script('tractor-express-Custome-js', 'custom_call', ['ajaxurl' => admin_url('admin-ajax.php'), 'homeurl' => home_url()]);
	wp_enqueue_script( 'tractor-express-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'tractor_express_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}


// function tractor_express_all_global_variable() {
//     global $phone, $phone_link, $address, $facebook_link, $instagram_link, $linkedin_link;
//     //Phone number
//     $phone = get_field('phone_number','option');
//     $val = array("(", ")", " ", "-", ".");
//     $replace = array("", "", "", "", "");
//     //Phone link
//     $phone_link = str_replace($val, $replace, $phone);
//     //Email
//     $address = get_field('address','option');
//     //Facebook link
//     $facebook_link= get_field('facebook_link','option');
//     //Instagram Link
//     $instagram_link= get_field('instagram_link','option');
//     //Linkedin Link
//     $linkedin_link= get_field('linkedin_link','option');

// }
// add_action( 'init', 'tractor_express_all_global_variable' );

add_filter( 'get_custom_logo', 'tractor_express_admin_logo_custom_title' );
// Filter the output of logo to fix Googles Error about itemprop logo
function tractor_express_admin_logo_custom_title() {
    $custom_logo_id = get_theme_mod( 'custom_logo' );
	$site_name = get_bloginfo( 'name' );
    $html = sprintf( '<a href="%1$s" class="custom-logo-link" rel="home" title="'.$site_name.'">%2$s</a>',
            esc_url( home_url( '/' ) ),
            wp_get_attachment_image( $custom_logo_id, 'full', false, array(
                'class'    => 'custom-logo',
				'alt'      => $site_name
            ) )
        );
    return $html;
}


